@@ -25,7 +25,7 @@ import asyncio
 import websockets
 from uuid import uuid4
 from json import loads, dumps
-from inspect import signature
+from inspect import signature, Parameter
 from logging import info, debug
 from typing import Awaitable, List, Union
 from websockets.exceptions import ConnectionClosedOK, ConnectionClosedError
@@ -56,7 +56,7 @@ def event(func: Awaitable):
     return func
 
 
-def command(name: str = None):
+def command(func: Awaitable = None, *, name: str = None):
     """
     Create a new command for dogehouse.
 
@@ -72,7 +72,7 @@ def command(name: str = None):
     def wrapper(func: Awaitable):
         commands[(name if name else func.__name__).lower()] = [func, False]
         return func
-    return wrapper
+    return wrapper(func) if func else wrapper
 
 
 class DogeClient(Repr):
@@ -141,9 +141,14 @@ class DogeClient(Repr):
                         arguments.append(ctx)
                         parameters.pop(0)
                         for idx, (key, param) in enumerate(parameters):
-                            value = args[idx]
-                            if param.kind == param.KEYWORD_ONLY:
-                                value = " ".join(args[idx::])
+                            if idx + 1 > len(args) and param.default != Parameter.empty:
+                                value = param.default
+                            else:
+                                value = args[idx]
+                                
+                                if param.kind == param.KEYWORD_ONLY:
+                                    value = " ".join(args[idx::])
+                            
                             params[key] = value
                     try:
                         asyncio.ensure_future(command[0](*arguments, **params))
@@ -190,11 +195,14 @@ class DogeClient(Repr):
                 elif op == "new_chat_msg":
                     msg = Message.from_dict(res["d"]["msg"])
                     await execute_listener("on_message", msg)
+                    
+                    if msg.author.id == self.user.id:
+                        continue
+                    
                     try:
                         async def handle_command(prefix: str):
                             if msg.content.startswith(prefix) and len(msg.content) > len(prefix) + 1:
-                                splitted = msg.content[len(
-                                    prefix)::].split(" ")
+                                splitted = msg.content[len(prefix)::].split(" ")
                                 await execute_command(splitted[0], msg, *splitted[1::])
                                 return True
                             return False
